@@ -7,17 +7,19 @@ import click
 import jsonschema
 import referencing.exceptions
 
-from . import utils
+from . import format_errors
 from .formats import FormatOptions
 from .instance_loader import InstanceLoader
 from .parsers import ParseError
+from .regex_variants import RegexImplementation
 from .reporter import Reporter
 from .result import CheckResult
 from .schema_loader import SchemaLoaderBase, SchemaParseError, UnsupportedUrlScheme
 
 
 class _Exit(Exception):
-    def __init__(self, code: int):
+    def __init__(self, code: int) -> None:
+        super().__init__(code)
         self.code = code
 
 
@@ -28,22 +30,24 @@ class SchemaChecker:
         instance_loader: InstanceLoader,
         reporter: Reporter,
         *,
-        format_opts: FormatOptions | None = None,
-        traceback_mode: str = "short",
+        format_opts: FormatOptions,
+        regex_impl: RegexImplementation,
+        traceback_mode: t.Literal["minimal", "short", "full"] = "short",
         fill_defaults: bool = False,
-    ):
+    ) -> None:
         self._schema_loader = schema_loader
         self._instance_loader = instance_loader
         self._reporter = reporter
 
-        self._format_opts = format_opts if format_opts is not None else FormatOptions()
+        self._format_opts = format_opts
+        self._regex_impl = regex_impl
         self._traceback_mode = traceback_mode
         self._fill_defaults = fill_defaults
 
     def _fail(self, msg: str, err: Exception | None = None) -> t.NoReturn:
         click.echo(msg, err=True)
         if err is not None:
-            utils.print_error(err, mode=self._traceback_mode)
+            format_errors.print_error(err, mode=self._traceback_mode)
         raise _Exit(1)
 
     def get_validator(
@@ -51,12 +55,12 @@ class SchemaChecker:
     ) -> jsonschema.protocols.Validator:
         try:
             return self._schema_loader.get_validator(
-                path, doc, self._format_opts, self._fill_defaults
+                path, doc, self._format_opts, self._regex_impl, self._fill_defaults
             )
         except SchemaParseError as e:
             self._fail("Error: schemafile could not be parsed as JSON", e)
         except jsonschema.SchemaError as e:
-            self._fail(f"Error: schemafile was not valid: {e}\n", e)
+            self._fail("Error: schemafile was not valid\n", e)
         except UnsupportedUrlScheme as e:
             self._fail(f"Error: {e}\n", e)
         except Exception as e:
